This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] testsuite: Follow spelling conventions.


Hi,

Attached is a patch to follow spelling conventions.  Committed as obvious.

Kazu Hirata

2002-09-16  Kazu Hirata  <kazu@cs.umass.edu>

	* ChangeLog: follow spelling conventions.
	* g++.old-deja/g++.abi/ptrmem.C: Likewise.
	* g++.old-deja/g++.bugs/900210_05.C: Likewise.
	* g++.old-deja/g++.bugs/900211_04.C: Likewise.
	* g++.old-deja/g++.bugs/900321_02.C: Likewise.
	* g++.old-deja/g++.bugs/900404_02.C: Likewise.
	* g++.old-deja/g++.bugs/900520_06.C: Likewise.
	* g++.old-deja/g++.law/global-init1.C: Likewise.
	* g++.old-deja/g++.other/delete4.C: Likewise.
	* g++.old-deja/g++.other/inline21.C: Likewise.
	* g++.old-deja/g++.other/singleton.C: Likewise.
	* g77.dg/strlen0.f: Likewise.
	* g77.f-torture/compile/20010519-1.f: Likewise.
	* g77.f-torture/compile/980310-4.f: Likewise.
	* gcc.c-torture/compile/20000605-1.c: Likewise.
	* gcc.c-torture/execute/20020225-1.c: Likewise.
	* gcc.dg/c90-hexfloat-2.c: Likewise.
	* gcc.dg/c99-bool-1.c: Likewise.
	* gcc.dg/c99-hexfloat-2.c: Likewise.
	* gcc.dg/dll-2.c: Likewise.
	* gcc.dg/wtr-union-init-1.c: Likewise.
	* gcc.dg/wtr-union-init-2.c: Likewise.
	* gcc.dg/wtr-union-init-3.c: Likewise.
	* gcc.dg/cpp/avoidpaste1.c: Likewise.
	* gcc.dg/cpp/defined.c: Likewise.
	* gcc.dg/cpp/macsyntx.c: Likewise.
	* gcc.dg/cpp/paste2.c: Likewise.
	* gcc.dg/cpp/trad/defined.c: Likewise.
	* gcc.dg/format/c90-printf-1.c: Likewise.
	* gcc.dg/format/c90-scanf-1.c: Likewise.
	* gcc.dg/format/c99-printf-1.c: Likewise.
	* gcc.dg/format/c99-scanf-1.c: Likewise.
	* gcc.misc-tests/gcov-8.c: Likewise.
	* lib/profopt.exp: Likewise.

Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/ChangeLog,v
retrieving revision 1.2073
diff -u -r1.2073 ChangeLog
--- ChangeLog	15 Sep 2002 18:54:43 -0000	1.2073
+++ ChangeLog	16 Sep 2002 11:57:43 -0000
@@ -310,7 +310,7 @@
 2002-07-26  Neil Booth  <neil@daikokuya.cop.uk>
 
 	* gcc.dg/cpp/trad/Wunused.c, gcc.dg/cpp/Wunused.c: Add test
-	for documented behaviour.
+	for documented behavior.
 
 2002-07-25  Roger Sayle  <roger@eyesopen.com>
 
@@ -2741,7 +2741,7 @@
 
 2001-12-28  Jakub Jelinek  <jakub@redhat.com>
 
-	* gcc.dg/gnu89-init-1.c: Adjust for the new behaviour, add some
+	* gcc.dg/gnu89-init-1.c: Adjust for the new behavior, add some
 	additional tests.
 
 2001-12-27  Roger Sayle <roger@eyesopen.com>
Index: g++.old-deja/g++.abi/ptrmem.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.abi/ptrmem.C,v
retrieving revision 1.8
diff -u -r1.8 ptrmem.C
--- g++.old-deja/g++.abi/ptrmem.C	22 Mar 2002 22:03:39 -0000	1.8
+++ g++.old-deja/g++.abi/ptrmem.C	16 Sep 2002 11:57:47 -0000
@@ -37,7 +37,7 @@
 };
 
 // Because S does not have a VPTR, it will not be a primary base of T,
-// and will therefore end up at a non-zero offset.
+// and will therefore end up at a nonzero offset.
 
 struct T : public S 
 {
Index: g++.old-deja/g++.bugs/900210_05.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.bugs/900210_05.C,v
retrieving revision 1.2
diff -u -r1.2 900210_05.C
--- g++.old-deja/g++.bugs/900210_05.C	16 Dec 1998 21:28:37 -0000	1.2
+++ g++.old-deja/g++.bugs/900210_05.C	16 Sep 2002 11:57:48 -0000
@@ -12,8 +12,8 @@
 // options come to mind.)
 
 // The use of errors rather than warnings is important because errors
-// usually result in non-zero exit status codes for language processors
-// and these non-zero exit stati can be automatically checked during
+// usually result in nonzero exit status codes for language processors
+// and these nonzero exit stati can be automatically checked during
 // normal execution of a Makefile.
 
 // cfront 2.0 provides the +p option which causes errors to be generated for
Index: g++.old-deja/g++.bugs/900211_04.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.bugs/900211_04.C,v
retrieving revision 1.2
diff -u -r1.2 900211_04.C
--- g++.old-deja/g++.bugs/900211_04.C	16 Dec 1998 21:28:46 -0000	1.2
+++ g++.old-deja/g++.bugs/900211_04.C	16 Sep 2002 11:57:48 -0000
@@ -1,7 +1,7 @@
 // g++ 1.36.1 bug 900211_04
 
 // g++ fails to flag as errors attempts to compare pointer values against
-// (non-zero) integer values;
+// (nonzero) integer values;
 
 // Since implicit conversions of pointer to integers (or vise versa) are
 // illegal, these comparisons are also illegal.
Index: g++.old-deja/g++.bugs/900321_02.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.bugs/900321_02.C,v
retrieving revision 1.2
diff -u -r1.2 900321_02.C
--- g++.old-deja/g++.bugs/900321_02.C	16 Dec 1998 21:29:03 -0000	1.2
+++ g++.old-deja/g++.bugs/900321_02.C	16 Sep 2002 11:57:48 -0000
@@ -1,6 +1,6 @@
 // g++ 1.37.1 bug 900321_02
 
-// The following program exits with a non-zero status because the constructor
+// The following program exits with a nonzero status because the constructor
 // is not called 3 times as it should be.  This program exits with a zero
 // status when compiled with cfront 2.0.
 
Index: g++.old-deja/g++.bugs/900404_02.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.bugs/900404_02.C,v
retrieving revision 1.2
diff -u -r1.2 900404_02.C
--- g++.old-deja/g++.bugs/900404_02.C	16 Dec 1998 21:29:24 -0000	1.2
+++ g++.old-deja/g++.bugs/900404_02.C	16 Sep 2002 11:57:48 -0000
@@ -3,7 +3,7 @@
 // g++ fails to treat multicharacter literals as type "int" as required by
 // section 2.5.2 of the C++ Reference Manual.
 
-// The result is that the following program will exit with a non-zero
+// The result is that the following program will exit with a nonzero
 // exit status.
 
 // keywords: character literals, multi-character literals, int type
Index: g++.old-deja/g++.bugs/900520_06.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.bugs/900520_06.C,v
retrieving revision 1.2
diff -u -r1.2 900520_06.C
--- g++.old-deja/g++.bugs/900520_06.C	16 Dec 1998 21:29:56 -0000	1.2
+++ g++.old-deja/g++.bugs/900520_06.C	16 Sep 2002 11:57:48 -0000
@@ -9,7 +9,7 @@
 // the class type when a parameter of the class type is passed as an
 // actual parameter.
 
-// This causes the following program to exit with a non-zero exit status.
+// This causes the following program to exit with a nonzero exit status.
 
 // cfront 2.0 passes this test.
 
Index: g++.old-deja/g++.law/global-init1.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.law/global-init1.C,v
retrieving revision 1.4
diff -u -r1.4 global-init1.C
--- g++.old-deja/g++.law/global-init1.C	22 Aug 2000 18:16:12 -0000	1.4
+++ g++.old-deja/g++.law/global-init1.C	16 Sep 2002 11:57:49 -0000
@@ -2,7 +2,7 @@
 // global-init file
 // Message-Id: <9212021756.AA12639@grumpy.pocs.com>
 // From: wp@pocs.com (Wolfgang Polak)
-// Subject: Initializers - gcc 2.2.2 (g++), Sparc, SunOS 4.1.1
+// Subject: Initializers - gcc 2.2.2 (g++), SPARC, SunOS 4.1.1
 // Date: Wed, 2 Dec 92 09:56:01 PST
 
 #include <stdio.h>
Index: g++.old-deja/g++.other/delete4.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.other/delete4.C,v
retrieving revision 1.2
diff -u -r1.2 delete4.C
--- g++.old-deja/g++.other/delete4.C	8 May 1999 16:39:17 -0000	1.2
+++ g++.old-deja/g++.other/delete4.C	16 Sep 2002 11:57:50 -0000
@@ -3,7 +3,7 @@
 // Copyright (C) 1999 Free Software Foundation, Inc.
 // Contributed by Nathan Sidwell 15 Apr 1999 <nathan@acm.org>
 
-// delete (void *)e and delete[] (void *)e result in undefined behaviour
+// delete (void *)e and delete[] (void *)e result in undefined behavior
 // [expr.delete/3]. Check we warn about them
 // operator new functions can only return NULL, if their exceptions
 // specification is `throw()'. All other cases must return a non-null pointer
Index: g++.old-deja/g++.other/inline21.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.other/inline21.C,v
retrieving revision 1.2
diff -u -r1.2 inline21.C
--- g++.old-deja/g++.other/inline21.C	25 May 2001 01:30:57 -0000	1.2
+++ g++.old-deja/g++.other/inline21.C	16 Sep 2002 11:57:50 -0000
@@ -18,7 +18,7 @@
 };
 
 
-// TEST FOR CORRECT BEHAVIOUR
+// TEST FOR CORRECT BEHAVIOR
 
 int myArray[3];
 int * intp = myArray;
Index: g++.old-deja/g++.other/singleton.C
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g++.old-deja/g++.other/singleton.C,v
retrieving revision 1.6
diff -u -r1.6 singleton.C
--- g++.old-deja/g++.other/singleton.C	16 Dec 1998 21:53:28 -0000	1.6
+++ g++.old-deja/g++.other/singleton.C	16 Sep 2002 11:57:50 -0000
@@ -4,7 +4,7 @@
 // egcs fails to see that there is a public static accessor function.
 // 2. the program crashes, because apparently the static variable s in
 // singleton::instance() is considered constructed although the ctor
-// exited via an exception. (crash changed to non-zero return here)
+// exited via an exception. (crash changed to nonzero return here)
 
 class singleton {
 public:
Index: g77.dg/strlen0.f
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g77.dg/strlen0.f,v
retrieving revision 1.1
diff -u -r1.1 strlen0.f
--- g77.dg/strlen0.f	22 Sep 2001 10:36:11 -0000	1.1
+++ g77.dg/strlen0.f	16 Sep 2002 11:57:51 -0000
@@ -28,7 +28,7 @@
 C
 C     This code compiles and runs without error on
 C       SunOS 4.1.3 f77 (-C option)
-C       SUNWspro SparcCompiler 4.2 f77 (-C option)
+C       SUNWspro SPARCcompiler 4.2 f77 (-C option)
 C       (and with proposed patches, gcc-2.9.2 -fbounds-check except for test 6,
 C        which is a genuine, deliberate error - comment out to make further
 C        tests)
Index: g77.f-torture/compile/20010519-1.f
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g77.f-torture/compile/20010519-1.f,v
retrieving revision 1.1
diff -u -r1.1 20010519-1.f
--- g77.f-torture/compile/20010519-1.f	19 May 2001 21:16:51 -0000	1.1
+++ g77.f-torture/compile/20010519-1.f	16 Sep 2002 11:57:53 -0000
@@ -15,7 +15,7 @@
 C     and: D.Perahia and L.Mouawad, Comput. Chem. (1995), 19, 241.
 C     The method iteratively solves the diagonalization of the
 C     Hessian matrix. To save memory space, it uses a compressed
-C     form of the Hessian, which only contains the non-zero elements.
+C     form of the Hessian, which only contains the nonzero elements.
 C     In the diagonalization process, approximate eigenvectors are
 C     mixed with Cartesian coordinates to form a reduced basis. The
 C     Hessian is then diagonalized in the reduced basis. By iterating
Index: g77.f-torture/compile/980310-4.f
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/g77.f-torture/compile/980310-4.f,v
retrieving revision 1.2
diff -u -r1.2 980310-4.f
--- g77.f-torture/compile/980310-4.f	16 Dec 1998 22:05:11 -0000	1.2
+++ g77.f-torture/compile/980310-4.f	16 Sep 2002 11:57:53 -0000
@@ -121,7 +121,7 @@
 c                         = 2 the occurrence of roundoff error is
 c                             detected, which prevents the requested
 c                             tolerance from being achieved.
-c                         = 3 extremely bad integrand behaviour occurs
+c                         = 3 extremely bad integrand behavior occurs
 c                             at some points of the integration
 c                             interval.
 c                         = 6 the input is invalid, because
@@ -303,7 +303,7 @@
 c
         if(last.eq.limit) ier = 1
 c
-c           set error flag in the case of bad integrand behaviour
+c           set error flag in the case of bad integrand behavior
 c           at a point of the integration range.
 c
         if(dmax1(dabs(a1),dabs(b2)).le.(0.1d+01+0.1d+03*
Index: gcc.c-torture/compile/20000605-1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.c-torture/compile/20000605-1.c,v
retrieving revision 1.1
diff -u -r1.1 20000605-1.c
--- gcc.c-torture/compile/20000605-1.c	5 Jun 2000 13:44:29 -0000	1.1
+++ gcc.c-torture/compile/20000605-1.c	16 Sep 2002 11:57:53 -0000
@@ -1,6 +1,6 @@
 /* Copyright (C) 2000 Free Software Foundation */
 
-/* make sure we don't get confused by various flavours of void */
+/* make sure we don't get confused by various flavors of void */
 
 /* Origin:  Jakub Jelinek  <jakub@redhat.com>
  *          Joel Sherrill <joel.sherrill@OARcorp.com>
Index: gcc.c-torture/execute/20020225-1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.c-torture/execute/20020225-1.c,v
retrieving revision 1.1
diff -u -r1.1 20020225-1.c
--- gcc.c-torture/execute/20020225-1.c	24 Feb 2002 23:17:23 -0000	1.1
+++ gcc.c-torture/execute/20020225-1.c	16 Sep 2002 11:57:54 -0000
@@ -1,5 +1,5 @@
 /* This testcase failed at -O2 on powerpc64 due to andsi3 writing
-   non-zero bits to the high 32 bits of a 64 bit register.  */
+   nonzero bits to the high 32 bits of a 64 bit register.  */
 
 extern void abort (void);
 extern void exit (int);
Index: gcc.dg/c90-hexfloat-2.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/c90-hexfloat-2.c,v
retrieving revision 1.1
diff -u -r1.1 c90-hexfloat-2.c
--- gcc.dg/c90-hexfloat-2.c	17 Jul 2000 08:27:13 -0000	1.1
+++ gcc.dg/c90-hexfloat-2.c	16 Sep 2002 11:57:55 -0000
@@ -20,5 +20,5 @@
   if (strcmp (s, "0x1p+( 0x1p+)"))
     abort ();
   else
-    return 0; /* Correct C90 behaviour.  */
+    return 0; /* Correct C90 behavior.  */
 }
Index: gcc.dg/c99-bool-1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/c99-bool-1.c,v
retrieving revision 1.2
diff -u -r1.2 c99-bool-1.c
--- gcc.dg/c99-bool-1.c	26 Apr 2002 07:24:39 -0000	1.2
+++ gcc.dg/c99-bool-1.c	16 Sep 2002 11:57:56 -0000
@@ -54,7 +54,7 @@
     abort ();
   if (a != 1 || b != 0 || c != 1)
     abort ();
-  /* Casts to _Bool have a specified behaviour.  */
+  /* Casts to _Bool have a specified behavior.  */
   if ((int)(_Bool)2 != 1)
     abort ();
   if ((int)(_Bool)0.2 != 1)
Index: gcc.dg/c99-hexfloat-2.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/c99-hexfloat-2.c,v
retrieving revision 1.1
diff -u -r1.1 c99-hexfloat-2.c
--- gcc.dg/c99-hexfloat-2.c	17 Jul 2000 08:27:13 -0000	1.1
+++ gcc.dg/c99-hexfloat-2.c	16 Sep 2002 11:57:56 -0000
@@ -20,5 +20,5 @@
   if (strcmp (s, "0x1p+f 0x1p+l"))
     abort ();
   else
-    return 0; /* Correct C99 behaviour.  */
+    return 0; /* Correct C99 behavior.  */
 }
Index: gcc.dg/dll-2.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/dll-2.c,v
retrieving revision 1.3
diff -u -r1.3 dll-2.c
--- gcc.dg/dll-2.c	16 Dec 1998 22:23:25 -0000	1.3
+++ gcc.dg/dll-2.c	16 Sep 2002 11:57:56 -0000
@@ -1,5 +1,5 @@
 /* These dllimport and dllexport appearing for a symbol.
-   The desired behaviour is that if both dllimport
+   The desired behavior is that if both dllimport
    and dllexport appear (in either order) the result is dllexport.
 
    Microsoft's MSVC 2.0 allows dllimport followed by dllexport for variables,
Index: gcc.dg/wtr-union-init-1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/wtr-union-init-1.c,v
retrieving revision 1.3
diff -u -r1.3 wtr-union-init-1.c
--- gcc.dg/wtr-union-init-1.c	3 Jul 2002 02:41:34 -0000	1.3
+++ gcc.dg/wtr-union-init-1.c	16 Sep 2002 11:57:56 -0000
@@ -13,7 +13,7 @@
 void
 testfunc ()
 {
-  /* Note we only warn for non-zero initializers.  */
+  /* Note we only warn for nonzero initializers.  */
   static union foo f1 = { 0 };
   static union foo f2 = { 1 }; /* { dg-warning "traditional C rejects initialization of unions" "initialization of unions" } */
 
Index: gcc.dg/wtr-union-init-2.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/wtr-union-init-2.c,v
retrieving revision 1.3
diff -u -r1.3 wtr-union-init-2.c
--- gcc.dg/wtr-union-init-2.c	3 Jul 2002 02:41:34 -0000	1.3
+++ gcc.dg/wtr-union-init-2.c	16 Sep 2002 11:57:56 -0000
@@ -21,7 +21,7 @@
 void
 testfunc ()
 {
-  /* Note we only warn for non-zero initializers.  */
+  /* Note we only warn for nonzero initializers.  */
   static union foo1 f1 = {0};
   static union foo2 f2 = {0};
   static union foo1 f3 = {1}; /* { dg-warning "traditional C rejects initialization of unions" "initialization of unions" } */
Index: gcc.dg/wtr-union-init-3.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/wtr-union-init-3.c,v
retrieving revision 1.3
diff -u -r1.3 wtr-union-init-3.c
--- gcc.dg/wtr-union-init-3.c	3 Jul 2002 02:41:34 -0000	1.3
+++ gcc.dg/wtr-union-init-3.c	16 Sep 2002 11:57:56 -0000
@@ -40,7 +40,7 @@
 void
 testfunc ()
 {
-  /* Note we only warn for non-zero initializers.  Xfail on substructures. */
+  /* Note we only warn for nonzero initializers.  Xfail on substructures. */
   static union foo f1 = {{0,0}}; /* { dg-bogus "traditional C rejects initialization of unions" "initialization of unions" { xfail *-*-* } } */
   static union foo f2 = {{1,1}}; /* { dg-warning "traditional C rejects initialization of unions" "initialization of unions" } */
 
Index: gcc.dg/cpp/avoidpaste1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/cpp/avoidpaste1.c,v
retrieving revision 1.4
diff -u -r1.4 avoidpaste1.c
--- gcc.dg/cpp/avoidpaste1.c	6 Feb 2001 19:09:39 -0000	1.4
+++ gcc.dg/cpp/avoidpaste1.c	16 Sep 2002 11:57:56 -0000
@@ -18,7 +18,7 @@
 : : : .. . 0 0 .
 
 It relies on the fact that even when preprocessing C we bother to separate
-the colons of C++'s :: operator.  If we confine this behaviour to C++
+the colons of C++'s :: operator.  If we confine this behavior to C++
 in future, this test needs to change.  */
 
 :: :g: :f(): :f(^): tricky
Index: gcc.dg/cpp/defined.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/cpp/defined.c,v
retrieving revision 1.3
diff -u -r1.3 defined.c
--- gcc.dg/cpp/defined.c	5 Nov 2001 22:26:13 -0000	1.3
+++ gcc.dg/cpp/defined.c	16 Sep 2002 11:57:56 -0000
@@ -2,7 +2,7 @@
 
 /* { dg-do preprocess } */
 
-/* Tests behaviour of the defined operator.  */
+/* Tests behavior of the defined operator.  */
 
 /*  Source: Neil Booth, 29 Oct 2000, Zack Weinberg 11 Dec 2000.  */
 
@@ -19,7 +19,7 @@
 #error Z is not defined
 #endif
 
-/* The behaviour of "defined" when it comes from a macro expansion is
+/* The behavior of "defined" when it comes from a macro expansion is
    now documented.  */
 #if is_Z_defined
 #error Macro expanding into defined operator test 1
@@ -51,7 +51,7 @@
 #error Z is not defined
 #endif
 
-/* The behaviour of "defined" when it comes from a macro expansion is
+/* The behavior of "defined" when it comes from a macro expansion is
    now documented.  */
 #if is_Z_defined
 #error Macro expanding into defined operator test 1
Index: gcc.dg/cpp/macsyntx.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/cpp/macsyntx.c,v
retrieving revision 1.8
diff -u -r1.8 macsyntx.c
--- gcc.dg/cpp/macsyntx.c	20 Nov 2000 18:28:43 -0000	1.8
+++ gcc.dg/cpp/macsyntx.c	16 Sep 2002 11:57:56 -0000
@@ -7,7 +7,7 @@
 
    o Full range of macro definition semantics.
    o No. of arguments supplied to function-like macros.
-   o Odd GNU rest args behaviour.
+   o Odd GNU rest args behavior.
    o Macro arguments do not flow into the rest of the file.  */
 
 
Index: gcc.dg/cpp/paste2.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/cpp/paste2.c,v
retrieving revision 1.4
diff -u -r1.4 paste2.c
--- gcc.dg/cpp/paste2.c	21 Nov 2000 00:00:50 -0000	1.4
+++ gcc.dg/cpp/paste2.c	16 Sep 2002 11:57:56 -0000
@@ -3,7 +3,7 @@
 /* { dg-do run } */
 /* { dg-options "-std=c99 -pedantic-errors" } */
 
-/* Test ## behaviour and corner cases thoroughly.  The macro expander
+/* Test ## behavior and corner cases thoroughly.  The macro expander
    failed many of these during development.  */
 
 #ifndef __WCHAR_TYPE__
Index: gcc.dg/cpp/trad/defined.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/cpp/trad/defined.c,v
retrieving revision 1.1
diff -u -r1.1 defined.c
--- gcc.dg/cpp/trad/defined.c	21 Jun 2002 05:29:09 -0000	1.1
+++ gcc.dg/cpp/trad/defined.c	16 Sep 2002 11:57:56 -0000
@@ -29,7 +29,7 @@
 #error Z is not defined
 #endif
 
-/* The behaviour of "defined" when it comes from a macro expansion is
+/* The behavior of "defined" when it comes from a macro expansion is
    now documented.  */
 #if is_Z_defined
 #error Macro expanding into defined operator test 1
@@ -61,7 +61,7 @@
 #error Z is not defined
 #endif
 
-/* The behaviour of "defined" when it comes from a macro expansion is
+/* The behavior of "defined" when it comes from a macro expansion is
    now documented.  */
 #if is_Z_defined
 #error Macro expanding into defined operator test 1
Index: gcc.dg/format/c90-scanf-1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/format/c90-scanf-1.c,v
retrieving revision 1.2
diff -u -r1.2 c90-scanf-1.c
--- gcc.dg/format/c90-scanf-1.c	7 Jan 2001 10:44:59 -0000	1.2
+++ gcc.dg/format/c90-scanf-1.c	16 Sep 2002 11:57:57 -0000
@@ -1,6 +1,6 @@
 /* Test for scanf formats.  Formats using C90 features, including cases
    where C90 specifies some aspect of the format to be ignored or where
-   the behaviour is undefined.
+   the behavior is undefined.
 */
 /* Origin: Joseph Myers <jsm28@cam.ac.uk> */
 /* { dg-do compile } */
Index: gcc.dg/format/c99-printf-1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/format/c99-printf-1.c,v
retrieving revision 1.2
diff -u -r1.2 c99-printf-1.c
--- gcc.dg/format/c99-printf-1.c	7 Jan 2001 10:44:59 -0000	1.2
+++ gcc.dg/format/c99-printf-1.c	16 Sep 2002 11:57:58 -0000
@@ -1,6 +1,6 @@
 /* Test for printf formats.  Formats using C99 features, including cases
    where C99 specifies some aspect of the format to be ignored or where
-   the behaviour is undefined.
+   the behavior is undefined.
 */
 /* Origin: Joseph Myers <jsm28@cam.ac.uk> */
 /* { dg-do compile } */
Index: gcc.dg/format/c99-scanf-1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/format/c99-scanf-1.c,v
retrieving revision 1.2
diff -u -r1.2 c99-scanf-1.c
--- gcc.dg/format/c99-scanf-1.c	7 Jan 2001 10:44:59 -0000	1.2
+++ gcc.dg/format/c99-scanf-1.c	16 Sep 2002 11:57:58 -0000
@@ -1,6 +1,6 @@
 /* Test for scanf formats.  Formats using C99 features, including cases
    where C99 specifies some aspect of the format to be ignored or where
-   the behaviour is undefined.
+   the behavior is undefined.
 */
 /* Origin: Joseph Myers <jsm28@cam.ac.uk> */
 /* { dg-do compile } */
Index: gcc.misc-tests/gcov-8.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.misc-tests/gcov-8.c,v
retrieving revision 1.1
diff -u -r1.1 gcov-8.c
--- gcc.misc-tests/gcov-8.c	5 Aug 2002 22:16:51 -0000	1.1
+++ gcc.misc-tests/gcov-8.c	16 Sep 2002 11:57:58 -0000
@@ -1,4 +1,4 @@
-/* Check that gcov correctly rounds nearly zero to non-zero and nearly
+/* Check that gcov correctly rounds nearly zero to nonzero and nearly
    100 to not-100.
 
    Copyright (C) 2002 Free Software Foundation, Inc.
Index: lib/profopt.exp
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/lib/profopt.exp,v
retrieving revision 1.1
diff -u -r1.1 profopt.exp
--- lib/profopt.exp	10 Sep 2001 21:37:44 -0000	1.1
+++ lib/profopt.exp	16 Sep 2002 11:57:58 -0000
@@ -27,7 +27,7 @@
 # addition to the profiling and feedback options.
 
 # If perf_ext is defined and the performance value for the
-# profile-directed test run is non-zero then the performance check will
+# profile-directed test run is nonzero then the performance check will
 # be done.
 
 global PROFOPT_OPTIONS perf_delta


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: gcc.dg/format/c90-printf-1.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/testsuite/gcc.dg/format/c90-printf-1.c,v
retrieving revision 1.2
diff -u -r1.2 c90-printf-1.c
--- gcc.dg/format/c90-printf-1.c	7 Jan 2001 10:44:59 -0000	1.2
+++ gcc.dg/format/c90-printf-1.c	16 Sep 2002 11:57:57 -0000
@@ -1,6 +1,6 @@
 /* Test for printf formats.  Formats using C90 features, including cases
    where C90 specifies some aspect of the format to be ignored or where
-   the behaviour is undefined.
+   the behavior is undefined.
 */
 /* Origin: Joseph Myers <jsm28@cam.ac.uk> */
 /* { dg-do compile } */
@@ -203,14 +203,14 @@
   printf ("%p%p%p%p", s, ss, us, css);
   /* %s allows any character type.  */
   printf ("%s%s%s%s", s, ss, us, css);
   /* Warning for void * arguments for %s is GCC's historical behaviour,
      and seems useful to keep, even if some standard versions might be
      read to permit it.
   */
   printf ("%s", p); /* { dg-warning "format" "bad argument types" } */
   /* The historical behaviour is to allow signed / unsigned types
      interchangably as arguments.  For values representable in both types,
-     such usage may be correct.  For now preserve the behaviour of GCC
+     such usage may be correct.  For now preserve the behavior of GCC
      in such cases.
   */
   printf ("%d", u);
@@ -203,14 +203,14 @@
   /* %s allows any character type.  */
   printf ("%s%s%s%s", s, ss, us, css);
-  /* Warning for void * arguments for %s is GCC's historical behaviour,
+  /* Warning for void * arguments for %s is GCC's historical behavior,
      and seems useful to keep, even if some standard versions might be
      read to permit it.
@@ -203,14 +203,14 @@
   */
   printf ("%s", p); /* { dg-warning "format" "bad argument types" } */
-  /* The historical behaviour is to allow signed / unsigned types
+  /* The historical behavior is to allow signed / unsigned types
      interchangably as arguments.  For values representable in both types,